% Wireless Communication & Signal Processing Group
% www.wcsp.eng.usf.edu
% Update 1: Alphan Sahin, Ertugrul Guvenkaya, 3/16/13

% This code requires Matlab Instrument Control Toolbox and
% WaveformDownloadAssistant function package which is available in Agilent
% website

%% Presetup
close all
clear all
clc
disp(['Welcome to WCSP Transmitter...'])
disp([''])
disp([''])

addpath(genpath('tools'))
%% Script Parameters
global parametersTransmitter;                    	% All transmitter parameters.
defaults;

%% Initialize Transmitter
transmitterObject = transmitterInitialization;

%% DATA
% Generate m-squences
trainingSequence=((mseq(2,parametersTransmitter.frame_seq_no) + 1)/2).'; % M-sequence
header=[randi([0 1],1,100) trainingSequence trainingSequence];
% Modulation
modemTX = modem.qammod('M', 2^parametersTransmitter.modulationOrder, 'SymbolOrder', 'Gray', 'InputType', 'bit');
modemTX.InputType = 'integer';
normCoef = sqrt(mean(abs(  modulate(modemTX,[0:2^parametersTransmitter.modulationOrder-1])    ).^2));
modemTX.InputType = 'bit';
frame = [header];

for i=1:1
    %% Use root-raised cosine as the pulse shaping filter
    modulatedFrame = [modulate(modemTX,reshape(frame,parametersTransmitter.modulationOrder,[]))/normCoef   zeros(1,0)]; % Generate IQ Symbols
    upsampledModulatedFrame=upsample(modulatedFrame, parametersTransmitter.oversampling_rate);
    filter_used = rrcosine(parametersTransmitter.roll_off_factor, parametersTransmitter.oversampling_rate, parametersTransmitter.number_of_symbols_in_filter, 1);
    packet=[ conv(filter_used,upsampledModulatedFrame) ];
    packet = packet/max(abs(packet)) / 10^(parametersTransmitter.backoff/20); % maximum amplitude for baseband signal is 1
    transmitData(transmitterObject, packet)
end